# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request, Response, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.meeting_recordings = MeetingRecordingService(self)
        self.meetings = MeetingService(self)
        self.reports = ReportService(self)
        self.room_configs = RoomConfigService(self)
        self.reserves = ReserveService(self)
        



class MeetingRecordingService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def get(self, user_access_token=None, timeout=None):
        # type: (str, int) -> MeetingRecordingGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MeetingRecordingGetReqCall(self, request_opts=request_opts)

    def stop(self, user_access_token=None, timeout=None):
        # type: (str, int) -> MeetingRecordingStopReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MeetingRecordingStopReqCall(self, request_opts=request_opts)

    def set_permission(self, body, user_access_token=None, timeout=None):
        # type: (MeetingRecordingSetPermissionReqBody, str, int) -> MeetingRecordingSetPermissionReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MeetingRecordingSetPermissionReqCall(self, body, request_opts=request_opts)

    def start(self, body, user_access_token=None, timeout=None):
        # type: (MeetingRecordingStartReqBody, str, int) -> MeetingRecordingStartReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MeetingRecordingStartReqCall(self, body, request_opts=request_opts)


class MeetingService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def invite(self, body, user_access_token=None, timeout=None):
        # type: (MeetingInviteReqBody, str, int) -> MeetingInviteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MeetingInviteReqCall(self, body, request_opts=request_opts)

    def list(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> MeetingListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MeetingListReqCall(self, request_opts=request_opts)

    def set_host(self, body, user_access_token=None, timeout=None):
        # type: (MeetingSetHostReqBody, str, int) -> MeetingSetHostReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MeetingSetHostReqCall(self, body, request_opts=request_opts)

    def end(self, user_access_token=None, timeout=None):
        # type: (str, int) -> MeetingEndReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MeetingEndReqCall(self, request_opts=request_opts)

    def get(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> MeetingGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return MeetingGetReqCall(self, request_opts=request_opts)


class ReportService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def get_top_user(self, tenant_key=None, timeout=None):
        # type: (str, int) -> ReportGetTopUserReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return ReportGetTopUserReqCall(self, request_opts=request_opts)

    def get_daily(self, tenant_key=None, timeout=None):
        # type: (str, int) -> ReportGetDailyReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return ReportGetDailyReqCall(self, request_opts=request_opts)


class RoomConfigService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def query(self, tenant_key=None, timeout=None):
        # type: (str, int) -> RoomConfigQueryReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return RoomConfigQueryReqCall(self, request_opts=request_opts)

    def set(self, body, tenant_key=None, timeout=None):
        # type: (RoomConfigSetReqBody, str, int) -> RoomConfigSetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return RoomConfigSetReqCall(self, body, request_opts=request_opts)


class ReserveService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def update(self, body, user_access_token=None, timeout=None):
        # type: (ReserveUpdateReqBody, str, int) -> ReserveUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return ReserveUpdateReqCall(self, body, request_opts=request_opts)

    def apply(self, body, user_access_token=None, timeout=None):
        # type: (ReserveApplyReqBody, str, int) -> ReserveApplyReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return ReserveApplyReqCall(self, body, request_opts=request_opts)

    def get(self, user_access_token=None, timeout=None):
        # type: (str, int) -> ReserveGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return ReserveGetReqCall(self, request_opts=request_opts)

    def get_active_meeting(self, user_access_token=None, timeout=None):
        # type: (str, int) -> ReserveGetActiveMeetingReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return ReserveGetActiveMeetingReqCall(self, request_opts=request_opts)

    def delete(self, user_access_token=None, timeout=None):
        # type: (str, int) -> ReserveDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return ReserveDeleteReqCall(self, request_opts=request_opts)



class RoomConfigQueryReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (RoomConfigService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_scope(self, scope):
        # type: (int) -> RoomConfigQueryReqCall
        self.query_params['scope'] = scope
        return self

    def set_country_id(self, countryId):
        # type: (int) -> RoomConfigQueryReqCall
        self.query_params['country_id'] = countryId
        return self

    def set_district_id(self, districtId):
        # type: (int) -> RoomConfigQueryReqCall
        self.query_params['district_id'] = districtId
        return self

    def set_building_id(self, buildingId):
        # type: (int) -> RoomConfigQueryReqCall
        self.query_params['building_id'] = buildingId
        return self

    def set_floor_name(self, floorName):
        # type: (str) -> RoomConfigQueryReqCall
        self.query_params['floor_name'] = floorName
        return self

    def set_room_id(self, roomId):
        # type: (int) -> RoomConfigQueryReqCall
        self.query_params['room_id'] = roomId
        return self

    def do(self):
        # type: () -> Response[RoomConfig]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/room_configs/query', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=RoomConfig, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MeetingInviteReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MeetingService, MeetingInviteReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_meeting_id(self, meetingId):
        # type: (int) -> MeetingInviteReqCall
        self.path_params['meeting_id'] = meetingId
        return self

    def set_user_id_type(self, userIdType):
        # type: (str) -> MeetingInviteReqCall
        self.query_params['user_id_type'] = userIdType
        return self

    def do(self):
        # type: () -> Response[MeetingInviteResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/meetings/:meeting_id/invite', 'PATCH', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=MeetingInviteResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MeetingListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (MeetingService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_room_id(self, roomId):
        # type: (int) -> MeetingListReqCall
        self.query_params['room_id'] = roomId
        return self

    def set_start_time(self, startTime):
        # type: (int) -> MeetingListReqCall
        self.query_params['start_time'] = startTime
        return self

    def set_end_time(self, endTime):
        # type: (int) -> MeetingListReqCall
        self.query_params['end_time'] = endTime
        return self

    def set_status(self, status):
        # type: (int) -> MeetingListReqCall
        self.query_params['status'] = status
        return self

    def set_page_token(self, pageToken):
        # type: (str) -> MeetingListReqCall
        self.query_params['page_token'] = pageToken
        return self

    def set_page_size(self, pageSize):
        # type: (int) -> MeetingListReqCall
        self.query_params['page_size'] = pageSize
        return self

    def do(self):
        # type: () -> Response[MeetingListResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/meetings', 'GET', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=MeetingListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class ReportGetTopUserReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (ReportService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_start_time(self, startTime):
        # type: (int) -> ReportGetTopUserReqCall
        self.query_params['start_time'] = startTime
        return self

    def set_end_time(self, endTime):
        # type: (int) -> ReportGetTopUserReqCall
        self.query_params['end_time'] = endTime
        return self

    def set_limit(self, limit):
        # type: (int) -> ReportGetTopUserReqCall
        self.query_params['limit'] = limit
        return self

    def set_order_by(self, orderBy):
        # type: (int) -> ReportGetTopUserReqCall
        self.query_params['order_by'] = orderBy
        return self

    def do(self):
        # type: () -> Response[ReportGetTopUserResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/reports/get_top_user', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=ReportGetTopUserResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MeetingSetHostReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MeetingService, MeetingSetHostReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_meeting_id(self, meetingId):
        # type: (int) -> MeetingSetHostReqCall
        self.path_params['meeting_id'] = meetingId
        return self

    def set_user_id_type(self, userIdType):
        # type: (str) -> MeetingSetHostReqCall
        self.query_params['user_id_type'] = userIdType
        return self

    def do(self):
        # type: () -> Response[MeetingSetHostResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/meetings/:meeting_id/set_host', 'PATCH', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=MeetingSetHostResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MeetingRecordingGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (MeetingRecordingService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_meeting_id(self, meetingId):
        # type: (int) -> MeetingRecordingGetReqCall
        self.path_params['meeting_id'] = meetingId
        return self

    def do(self):
        # type: () -> Response[MeetingRecordingGetResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('vc/v1/meetings/:meeting_id/recording', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=MeetingRecordingGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MeetingEndReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (MeetingService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_meeting_id(self, meetingId):
        # type: (int) -> MeetingEndReqCall
        self.path_params['meeting_id'] = meetingId
        return self

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('vc/v1/meetings/:meeting_id/end', 'PATCH', [ACCESS_TOKEN_TYPE_USER],
                      None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MeetingRecordingStopReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (MeetingRecordingService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_meeting_id(self, meetingId):
        # type: (int) -> MeetingRecordingStopReqCall
        self.path_params['meeting_id'] = meetingId
        return self

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('vc/v1/meetings/:meeting_id/recording/stop', 'PATCH', [ACCESS_TOKEN_TYPE_USER],
                      None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class ReportGetDailyReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (ReportService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_start_time(self, startTime):
        # type: (int) -> ReportGetDailyReqCall
        self.query_params['start_time'] = startTime
        return self

    def set_end_time(self, endTime):
        # type: (int) -> ReportGetDailyReqCall
        self.query_params['end_time'] = endTime
        return self

    def do(self):
        # type: () -> Response[ReportGetDailyResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/reports/get_daily', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=ReportGetDailyResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MeetingGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (MeetingService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_meeting_id(self, meetingId):
        # type: (int) -> MeetingGetReqCall
        self.path_params['meeting_id'] = meetingId
        return self

    def set_with_participants(self, withParticipants):
        # type: (bool) -> MeetingGetReqCall
        self.query_params['with_participants'] = withParticipants
        return self

    def set_with_meeting_ability(self, withMeetingAbility):
        # type: (bool) -> MeetingGetReqCall
        self.query_params['with_meeting_ability'] = withMeetingAbility
        return self

    def set_user_id_type(self, userIdType):
        # type: (str) -> MeetingGetReqCall
        self.query_params['user_id_type'] = userIdType
        return self

    def do(self):
        # type: () -> Response[MeetingGetResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/meetings/:meeting_id', 'GET', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=MeetingGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class RoomConfigSetReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (RoomConfigService, RoomConfigSetReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('vc/v1/room_configs/set', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                      self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MeetingRecordingSetPermissionReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MeetingRecordingService, MeetingRecordingSetPermissionReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_meeting_id(self, meetingId):
        # type: (int) -> MeetingRecordingSetPermissionReqCall
        self.path_params['meeting_id'] = meetingId
        return self

    def set_user_id_type(self, userIdType):
        # type: (str) -> MeetingRecordingSetPermissionReqCall
        self.query_params['user_id_type'] = userIdType
        return self

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/meetings/:meeting_id/recording/set_permission', 'PATCH', [ACCESS_TOKEN_TYPE_USER],
                      self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class MeetingRecordingStartReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (MeetingRecordingService, MeetingRecordingStartReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_meeting_id(self, meetingId):
        # type: (int) -> MeetingRecordingStartReqCall
        self.path_params['meeting_id'] = meetingId
        return self

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('vc/v1/meetings/:meeting_id/recording/start', 'PATCH', [ACCESS_TOKEN_TYPE_USER],
                      self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class ReserveUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (ReserveService, ReserveUpdateReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_reserve_id(self, reserveId):
        # type: (int) -> ReserveUpdateReqCall
        self.path_params['reserve_id'] = reserveId
        return self

    def set_user_id_type(self, userIdType):
        # type: (str) -> ReserveUpdateReqCall
        self.query_params['user_id_type'] = userIdType
        return self

    def do(self):
        # type: () -> Response[ReserveUpdateResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/reserves/:reserve_id', 'PUT', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=ReserveUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class ReserveApplyReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (ReserveService, ReserveApplyReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_user_id_type(self, userIdType):
        # type: (str) -> ReserveApplyReqCall
        self.query_params['user_id_type'] = userIdType
        return self

    def do(self):
        # type: () -> Response[ReserveApplyResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/reserves/apply', 'POST', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=ReserveApplyResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class ReserveGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (ReserveService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_reserve_id(self, reserveId):
        # type: (int) -> ReserveGetReqCall
        self.path_params['reserve_id'] = reserveId
        return self

    def do(self):
        # type: () -> Response[ReserveGetResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('vc/v1/reserves/:reserve_id', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=ReserveGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class ReserveGetActiveMeetingReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (ReserveService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_reserve_id(self, reserveId):
        # type: (int) -> ReserveGetActiveMeetingReqCall
        self.path_params['reserve_id'] = reserveId
        return self

    def set_with_participants(self, withParticipants):
        # type: (bool) -> ReserveGetActiveMeetingReqCall
        self.query_params['with_participants'] = withParticipants
        return self

    def do(self):
        # type: () -> Response[ReserveGetActiveMeetingResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('vc/v1/reserves/:reserve_id/get_active_meeting', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=ReserveGetActiveMeetingResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class ReserveDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (ReserveService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_reserve_id(self, reserveId):
        # type: (int) -> ReserveDeleteReqCall
        self.path_params['reserve_id'] = reserveId
        return self

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('vc/v1/reserves/:reserve_id', 'DELETE', [ACCESS_TOKEN_TYPE_USER],
                      None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class Mailgroup(object):
    mailgroup_id = attr.ib(type=str, default=None, metadata={'json': 'mailgroup_id'})
    email = attr.ib(type=str, default=None, metadata={'json': 'email'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    description = attr.ib(type=str, default=None, metadata={'json': 'description'})
    direct_members_count = attr.ib(type=str, default=None, metadata={'json': 'direct_members_count'})
    include_external_member = attr.ib(type=bool, default=None, metadata={'json': 'include_external_member'})
    include_all_company_member = attr.ib(type=bool, default=None, metadata={'json': 'include_all_company_member'})
    who_can_send_mail = attr.ib(type=str, default=None, metadata={'json': 'who_can_send_mail'})


@to_json_decorator
@attr.s
class MailgroupMember(object):
    member_id = attr.ib(type=str, default=None, metadata={'json': 'member_id'})
    email = attr.ib(type=str, default=None, metadata={'json': 'email'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    department_id = attr.ib(type=str, default=None, metadata={'json': 'department_id'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})


@to_json_decorator
@attr.s
class MailgroupPermissionMember(object):
    permission_member_id = attr.ib(type=str, default=None, metadata={'json': 'permission_member_id'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    department_id = attr.ib(type=str, default=None, metadata={'json': 'department_id'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})


@to_json_decorator
@attr.s
class PublicMailbox(object):
    public_mailbox_id = attr.ib(type=str, default=None, metadata={'json': 'public_mailbox_id'})
    email = attr.ib(type=str, default=None, metadata={'json': 'email'})
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})


@to_json_decorator
@attr.s
class PublicMailboxMember(object):
    member_id = attr.ib(type=str, default=None, metadata={'json': 'member_id'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})










@attr.s
class MailgroupMemberListResult(object):
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    items = attr.ib(type=List[MailgroupMember], default=None, metadata={'json': 'items'})





@attr.s
class MailgroupPermissionMemberListResult(object):
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    items = attr.ib(type=List[MailgroupPermissionMember], default=None, metadata={'json': 'items'})







@attr.s
class PublicMailboxMemberListResult(object):
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    items = attr.ib(type=List[PublicMailboxMember], default=None, metadata={'json': 'items'})









@attr.s
class PublicMailboxListResult(object):
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    items = attr.ib(type=List[PublicMailbox], default=None, metadata={'json': 'items'})

















@attr.s
class MailgroupListResult(object):
    has_more = attr.ib(type=bool, default=None, metadata={'json': 'has_more'})
    page_token = attr.ib(type=str, default=None, metadata={'json': 'page_token'})
    items = attr.ib(type=List[Mailgroup], default=None, metadata={'json': 'items'})








# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict
from ....utils.dt import to_json_decorator
from ....event.model.event import *
import attr




@to_json_decorator
@attr.s
class Application(object):
    pass


@to_json_decorator
@attr.s
class UserId(object):
    open_id = attr.ib(type=str, default=None, metadata={'json': 'open_id'})
    user_id = attr.ib(type=str, default=None, metadata={'json': 'user_id'})



@attr.s
class AppOpenEventData(object):
    app_id = attr.ib(type=str, default=None, metadata={'json': 'app_id'})
    tenant_key = attr.ib(type=str, default=None, metadata={'json': 'tenant_key'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})
    applicants = attr.ib(type=List[UserId], default=None, metadata={'json': 'applicants'})
    installer = attr.ib(type=UserId, default=None, metadata={'json': 'installer'})

@attr.s
class AppOpenEvent(BaseEvent):
    event = attr.ib(type=AppOpenEventData, default=None)



@attr.s
class AppStatusChangeEventData(object):
    app_id = attr.ib(type=str, default=None, metadata={'json': 'app_id'})
    tenant_key = attr.ib(type=str, default=None, metadata={'json': 'tenant_key'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})
    status = attr.ib(type=str, default=None, metadata={'json': 'status'})

@attr.s
class AppStatusChangeEvent(BaseEvent):
    event = attr.ib(type=AppStatusChangeEventData, default=None)



@attr.s
class AppUninstalledEventData(object):
    app_id = attr.ib(type=str, default=None, metadata={'json': 'app_id'})
    tenant_key = attr.ib(type=str, default=None, metadata={'json': 'tenant_key'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})

@attr.s
class AppUninstalledEvent(BaseEvent):
    event = attr.ib(type=AppUninstalledEventData, default=None)



@attr.s
class OrderPaidEventData(object):
    app_id = attr.ib(type=str, default=None, metadata={'json': 'app_id'})
    tenant_key = attr.ib(type=str, default=None, metadata={'json': 'tenant_key'})
    type = attr.ib(type=str, default=None, metadata={'json': 'type'})
    order_id = attr.ib(type=str, default=None, metadata={'json': 'order_id'})
    price_plan_id = attr.ib(type=str, default=None, metadata={'json': 'price_plan_id'})
    price_plan_type = attr.ib(type=str, default=None, metadata={'json': 'price_plan_type'})
    seats = attr.ib(type=int, default=None, metadata={'json': 'seats'})
    buy_count = attr.ib(type=int, default=None, metadata={'json': 'buy_count'})
    create_time = attr.ib(type=str, default=None, metadata={'json': 'create_time'})
    pay_time = attr.ib(type=str, default=None, metadata={'json': 'pay_time'})
    buy_type = attr.ib(type=str, default=None, metadata={'json': 'buy_type'})
    src_order_id = attr.ib(type=str, default=None, metadata={'json': 'src_order_id'})
    order_pay_price = attr.ib(type=int, default=None, metadata={'json': 'order_pay_price'})

@attr.s
class OrderPaidEvent(BaseEvent):
    event = attr.ib(type=OrderPaidEventData, default=None)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import Callable

from ....config import Config
from ....context import Context
from ....event.event import set_event_callback

from .model import *


class DepartmentCreatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, DepartmentCreatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, DepartmentCreatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, DepartmentCreatedEvent], Any]) -> None
        handler = DepartmentCreatedEventHandler(callback)
        set_event_callback(conf, "contact.department.created_v3",
                          handler.handle, clazz=DepartmentCreatedEvent)


class DepartmentDeletedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, DepartmentDeletedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, DepartmentDeletedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, DepartmentDeletedEvent], Any]) -> None
        handler = DepartmentDeletedEventHandler(callback)
        set_event_callback(conf, "contact.department.deleted_v3",
                          handler.handle, clazz=DepartmentDeletedEvent)


class DepartmentUpdatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, DepartmentUpdatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, DepartmentUpdatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, DepartmentUpdatedEvent], Any]) -> None
        handler = DepartmentUpdatedEventHandler(callback)
        set_event_callback(conf, "contact.department.updated_v3",
                          handler.handle, clazz=DepartmentUpdatedEvent)


class UserCreatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, UserCreatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, UserCreatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, UserCreatedEvent], Any]) -> None
        handler = UserCreatedEventHandler(callback)
        set_event_callback(conf, "contact.user.created_v3",
                          handler.handle, clazz=UserCreatedEvent)


class UserDeletedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, UserDeletedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, UserDeletedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, UserDeletedEvent], Any]) -> None
        handler = UserDeletedEventHandler(callback)
        set_event_callback(conf, "contact.user.deleted_v3",
                          handler.handle, clazz=UserDeletedEvent)


class UserUpdatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, UserUpdatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, UserUpdatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, UserUpdatedEvent], Any]) -> None
        handler = UserUpdatedEventHandler(callback)
        set_event_callback(conf, "contact.user.updated_v3",
                          handler.handle, clazz=UserUpdatedEvent)


class UserGroupCreatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, UserGroupCreatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, UserGroupCreatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, UserGroupCreatedEvent], Any]) -> None
        handler = UserGroupCreatedEventHandler(callback)
        set_event_callback(conf, "contact.user_group.created_v3",
                          handler.handle, clazz=UserGroupCreatedEvent)


class UserGroupDeletedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, UserGroupDeletedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, UserGroupDeletedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, UserGroupDeletedEvent], Any]) -> None
        handler = UserGroupDeletedEventHandler(callback)
        set_event_callback(conf, "contact.user_group.deleted_v3",
                          handler.handle, clazz=UserGroupDeletedEvent)


class UserGroupUpdatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, UserGroupUpdatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, UserGroupUpdatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, UserGroupUpdatedEvent], Any]) -> None
        handler = UserGroupUpdatedEventHandler(callback)
        set_event_callback(conf, "contact.user_group.updated_v3",
                          handler.handle, clazz=UserGroupUpdatedEvent)


class ScopeUpdatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, ScopeUpdatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, ScopeUpdatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, ScopeUpdatedEvent], Any]) -> None
        handler = ScopeUpdatedEventHandler(callback)
        set_event_callback(conf, "contact.scope.updated_v3",
                          handler.handle, clazz=ScopeUpdatedEvent)


class UserGroupMemberChangedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, UserGroupMemberChangedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, UserGroupMemberChangedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, UserGroupMemberChangedEvent], Any]) -> None
        handler = UserGroupMemberChangedEventHandler(callback)
        set_event_callback(conf, "contact.user_group.member.changed_v3",
                          handler.handle, clazz=UserGroupMemberChangedEvent)


class CustomAttrEventUpdatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, CustomAttrEventUpdatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, CustomAttrEventUpdatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, CustomAttrEventUpdatedEvent], Any]) -> None
        handler = CustomAttrEventUpdatedEventHandler(callback)
        set_event_callback(conf, "contact.custom_attr_event.updated_v3",
                          handler.handle, clazz=CustomAttrEventUpdatedEvent)


class EmployeeTypeEnumActivedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, EmployeeTypeEnumActivedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, EmployeeTypeEnumActivedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, EmployeeTypeEnumActivedEvent], Any]) -> None
        handler = EmployeeTypeEnumActivedEventHandler(callback)
        set_event_callback(conf, "contact.employee_type_enum.actived_v3",
                          handler.handle, clazz=EmployeeTypeEnumActivedEvent)


class EmployeeTypeEnumCreatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, EmployeeTypeEnumCreatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, EmployeeTypeEnumCreatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, EmployeeTypeEnumCreatedEvent], Any]) -> None
        handler = EmployeeTypeEnumCreatedEventHandler(callback)
        set_event_callback(conf, "contact.employee_type_enum.created_v3",
                          handler.handle, clazz=EmployeeTypeEnumCreatedEvent)


class EmployeeTypeEnumDeactivatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, EmployeeTypeEnumDeactivatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, EmployeeTypeEnumDeactivatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, EmployeeTypeEnumDeactivatedEvent], Any]) -> None
        handler = EmployeeTypeEnumDeactivatedEventHandler(callback)
        set_event_callback(conf, "contact.employee_type_enum.deactivated_v3",
                          handler.handle, clazz=EmployeeTypeEnumDeactivatedEvent)


class EmployeeTypeEnumDeletedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, EmployeeTypeEnumDeletedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, EmployeeTypeEnumDeletedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, EmployeeTypeEnumDeletedEvent], Any]) -> None
        handler = EmployeeTypeEnumDeletedEventHandler(callback)
        set_event_callback(conf, "contact.employee_type_enum.deleted_v3",
                          handler.handle, clazz=EmployeeTypeEnumDeletedEvent)


class EmployeeTypeEnumUpdatedEventHandler(object):
    def __init__(self, callback):
        # type: (Callable[[Context, Config, EmployeeTypeEnumUpdatedEvent], Any]) -> None
        self.handler = callback

    def handle(self, ctx, conf, event):  # type: (Context, Config, EmployeeTypeEnumUpdatedEvent) -> Any
        return self.handler(ctx, conf, event)

    @staticmethod
    def set_callback(conf, callback):
        # type: (Config, Callable[[Context, Config, EmployeeTypeEnumUpdatedEvent], Any]) -> None
        handler = EmployeeTypeEnumUpdatedEventHandler(callback)
        set_event_callback(conf, "contact.employee_type_enum.updated_v3",
                          handler.handle, clazz=EmployeeTypeEnumUpdatedEvent)



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request, Response, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.buildings = BuildingService(self)
        self.countrys = CountryService(self)
        self.districts = DistrictService(self)
        self.freebusys = FreebusyService(self)
        self.instances = InstanceService(self)
        self.rooms = RoomService(self)
        self.summarys = SummaryService(self)
        self.meeting_rooms = MeetingRoomService(self)
        



class BuildingService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def batch_get(self, tenant_key=None, timeout=None):
        # type: (str, int) -> BuildingBatchGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return BuildingBatchGetReqCall(self, request_opts=request_opts)

    def batch_get_id(self, tenant_key=None, timeout=None):
        # type: (str, int) -> BuildingBatchGetIdReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return BuildingBatchGetIdReqCall(self, request_opts=request_opts)

    def create(self, body, tenant_key=None, timeout=None):
        # type: (BuildingCreateReqBody, str, int) -> BuildingCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return BuildingCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> BuildingDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return BuildingDeleteReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> BuildingListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return BuildingListReqCall(self, request_opts=request_opts)

    def update(self, body, tenant_key=None, timeout=None):
        # type: (BuildingUpdateReqBody, str, int) -> BuildingUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return BuildingUpdateReqCall(self, body, request_opts=request_opts)


class CountryService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> CountryListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return CountryListReqCall(self, request_opts=request_opts)


class DistrictService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> DistrictListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return DistrictListReqCall(self, request_opts=request_opts)


class FreebusyService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def batch_get(self, tenant_key=None, timeout=None):
        # type: (str, int) -> FreebusyBatchGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return FreebusyBatchGetReqCall(self, request_opts=request_opts)


class InstanceService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def reply(self, body, tenant_key=None, timeout=None):
        # type: (InstanceReplyReqBody, str, int) -> InstanceReplyReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return InstanceReplyReqCall(self, body, request_opts=request_opts)


class RoomService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def batch_get(self, tenant_key=None, timeout=None):
        # type: (str, int) -> RoomBatchGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return RoomBatchGetReqCall(self, request_opts=request_opts)

    def batch_get_id(self, tenant_key=None, timeout=None):
        # type: (str, int) -> RoomBatchGetIdReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return RoomBatchGetIdReqCall(self, request_opts=request_opts)

    def create(self, body, tenant_key=None, timeout=None):
        # type: (RoomCreateReqBody, str, int) -> RoomCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return RoomCreateReqCall(self, body, request_opts=request_opts)

    def delete(self, tenant_key=None, timeout=None):
        # type: (str, int) -> RoomDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return RoomDeleteReqCall(self, request_opts=request_opts)

    def list(self, tenant_key=None, timeout=None):
        # type: (str, int) -> RoomListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return RoomListReqCall(self, request_opts=request_opts)

    def update(self, body, tenant_key=None, timeout=None):
        # type: (RoomUpdateReqBody, str, int) -> RoomUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return RoomUpdateReqCall(self, body, request_opts=request_opts)


class SummaryService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def batch_get(self, body, tenant_key=None, timeout=None):
        # type: (SummaryBatchGetReqBody, str, int) -> SummaryBatchGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return SummaryBatchGetReqCall(self, body, request_opts=request_opts)


class MeetingRoomService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service



class RoomBatchGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (RoomService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_room_ids(self, room_ids):
        # type: (List[str]) -> RoomBatchGetReqCall
        self.query_params['room_ids'] = room_ids
        return self

    def set_fields(self, fields):
        # type: (str) -> RoomBatchGetReqCall
        self.query_params['fields'] = fields
        return self

    def do(self):
        # type: () -> Response[RoomBatchGetResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('meeting_room/room/batch_get', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=RoomBatchGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FreebusyBatchGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (FreebusyService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_room_ids(self, room_ids):
        # type: (List[str]) -> FreebusyBatchGetReqCall
        self.query_params['room_ids'] = room_ids
        return self

    def set_time_min(self, time_min):
        # type: (str) -> FreebusyBatchGetReqCall
        self.query_params['time_min'] = time_min
        return self

    def set_time_max(self, time_max):
        # type: (str) -> FreebusyBatchGetReqCall
        self.query_params['time_max'] = time_max
        return self

    def do(self):
        # type: () -> Response[FreebusyBatchGetResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('meeting_room/freebusy/batch_get', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=FreebusyBatchGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class SummaryBatchGetReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (SummaryService, SummaryBatchGetReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[SummaryBatchGetResult]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('meeting_room/summary/batch_get', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                      self.body, output_class=SummaryBatchGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class BuildingBatchGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (BuildingService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_building_ids(self, building_ids):
        # type: (List[str]) -> BuildingBatchGetReqCall
        self.query_params['building_ids'] = building_ids
        return self

    def set_fields(self, fields):
        # type: (str) -> BuildingBatchGetReqCall
        self.query_params['fields'] = fields
        return self

    def do(self):
        # type: () -> Response[BuildingBatchGetResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('meeting_room/building/batch_get', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=BuildingBatchGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class BuildingBatchGetIdReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (BuildingService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_custom_building_ids(self, custom_building_ids):
        # type: (List[str]) -> BuildingBatchGetIdReqCall
        self.query_params['custom_building_ids'] = custom_building_ids
        return self

    def do(self):
        # type: () -> Response[BuildingBatchGetIdResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('meeting_room/building/batch_get_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=BuildingBatchGetIdResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class RoomBatchGetIdReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (RoomService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_custom_room_ids(self, custom_room_ids):
        # type: (List[str]) -> RoomBatchGetIdReqCall
        self.query_params['custom_room_ids'] = custom_room_ids
        return self

    def do(self):
        # type: () -> Response[RoomBatchGetIdResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('meeting_room/room/batch_get_id', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=RoomBatchGetIdResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class BuildingCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (BuildingService, BuildingCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[BuildingCreateResult]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('meeting_room/building/create', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                      self.body, output_class=BuildingCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class RoomCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (RoomService, RoomCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[RoomCreateResult]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('meeting_room/room/create', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                      self.body, output_class=RoomCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class BuildingDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (BuildingService, List[Any]) -> None

        self.service = service
        

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('meeting_room/building/delete', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                      None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class RoomDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (RoomService, List[Any]) -> None

        self.service = service
        

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('meeting_room/room/delete', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                      None, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class CountryListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (CountryService, List[Any]) -> None

        self.service = service
        

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[CountryListResult]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('meeting_room/country/list', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=CountryListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class RoomListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (RoomService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_building_id(self, building_id):
        # type: (str) -> RoomListReqCall
        self.query_params['building_id'] = building_id
        return self

    def set_order_by(self, order_by):
        # type: (str) -> RoomListReqCall
        self.query_params['order_by'] = order_by
        return self

    def set_fields(self, fields):
        # type: (str) -> RoomListReqCall
        self.query_params['fields'] = fields
        return self

    def set_page_token(self, page_token):
        # type: (str) -> RoomListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> RoomListReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> Response[RoomListResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('meeting_room/room/list', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=RoomListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DistrictListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DistrictService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_country_id(self, country_id):
        # type: (int) -> DistrictListReqCall
        self.query_params['country_id'] = country_id
        return self

    def do(self):
        # type: () -> Response[DistrictListResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('meeting_room/district/list', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=DistrictListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class BuildingListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (BuildingService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_order_by(self, order_by):
        # type: (str) -> BuildingListReqCall
        self.query_params['order_by'] = order_by
        return self

    def set_fields(self, fields):
        # type: (str) -> BuildingListReqCall
        self.query_params['fields'] = fields
        return self

    def set_page_token(self, page_token):
        # type: (str) -> BuildingListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> BuildingListReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> Response[BuildingListResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('meeting_room/building/list', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=BuildingListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class InstanceReplyReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (InstanceService, InstanceReplyReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('meeting_room/instance/reply', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                      self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class RoomUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (RoomService, RoomUpdateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('meeting_room/room/update', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                      self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class BuildingUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (BuildingService, BuildingUpdateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('meeting_room/building/update', 'POST', [ACCESS_TOKEN_TYPE_TENANT],
                      self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
import os
import tempfile
from typing import IO, Any, Dict, List, Tuple, Union


class FormDataFile(object):
    def __init__(self, content, file_name='unkown', mime_type=''):
        # type: (Union[bytes, IO[Any]], str, str) -> None
        self.name = file_name
        self.type = mime_type
        self.content = content
        self.file_path = None
        self.__prepared = False  # type: bool
        self.field_name = ''  # type: str

    def prepare(self):
        if self.__prepared:
            return
        tmp_file_path = tempfile.mktemp('.larksuiteoapisdk')
        current_file = self.content  # type: Union[IO[Any], bytes]
        tmp_file = open(tmp_file_path, 'wb')
        if isinstance(current_file, bytes):
            current_file_bytes = current_file
            tmp_file.write(current_file_bytes)
        else:
            for content in current_file:
                tmp_file.write(content)
        tmp_file.flush()
        tmp_file.close()
        self.file_path = tmp_file_path
        self.__prepared = True

    def delete(self):
        if self.file_path:
            os.remove(self.file_path)


class FormData(object):
    def __init__(self, files=None, params=None):
        # type: (Union[None, List[FormDataFile]], Union[None, Dict[str, Union[bytes, str]]]) -> None
        if files is None:
            files = []
        if params is None:
            params = {}
        self.files = files
        self.params = params

    def __str__(self):
        return "params:%s, file count:%s" % (self.params, len(self.files))

    def to_map(self):
        # type: () -> Tuple[List[Tuple[str, Tuple[str, IO, str]]], Dict[str, str], List[IO]]

        ret_files = []  # type: List[Tuple[str, Tuple[str, Union[bytes, IO], str]]]
        ret_data = {}  # type: Dict[str, Union[bytes, str]]
        need_close = []  # type: List[IO[Any]]

        for file in self.files:
            content = file.content
            if file.file_path is not None:
                content = open(file.file_path, 'rb')
                need_close += [content]
            if content is None:
                continue
            if file.type != '':
                f = (file.field_name, (file.name, content, file.type))
            else:
                f = (file.field_name, (file.name, content, 'application/octet-stream'))
            ret_files += [f]

        for key, value in self.params.items():
            ret_data[key] = value

        return ret_files, ret_data, need_close

    def delete_tmp_files(self):
        for file in self.files:
            file.delete()

    def add_param(self, field_name, val):  # type: (str, str) -> None
        self.params[field_name] = val

    def add_file(self, field_name, file):
        # type: (str, FormDataFile) -> None
        file.field_name = field_name
        self.files += [file]



# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request, Response, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.face_verifys = FaceVerifyService(self)
        



class FaceVerifyService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def crop_face_image(self, tenant_key=None, timeout=None):
        # type: (str, int) -> FaceVerifyCropFaceImageReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return FaceVerifyCropFaceImageReqCall(self, request_opts=request_opts)

    def query_auth_result(self, tenant_key=None, timeout=None):
        # type: (str, int) -> FaceVerifyQueryAuthResultReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return FaceVerifyQueryAuthResultReqCall(self, request_opts=request_opts)

    def upload_face_image(self, tenant_key=None, timeout=None):
        # type: (str, int) -> FaceVerifyUploadFaceImageReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        return FaceVerifyUploadFaceImageReqCall(self, request_opts=request_opts)



class FaceVerifyCropFaceImageReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (FaceVerifyService, List[Any]) -> None

        self.service = service
        self.body = FormData()

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_raw_image(self, raw_image):
        # type: (IO[Any]) -> FaceVerifyCropFaceImageReqCall
        self.body.add_file('raw_image', FormDataFile(raw_image))
        return self

    def do(self):
        # type: () -> Response[FaceVerifyCropFaceImageResult]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('face_verify/v1/crop_face_image', 'POST', [ACCESS_TOKEN_TYPE_TENANT], self.body, output_class=FaceVerifyCropFaceImageResult , request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FaceVerifyQueryAuthResultReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (FaceVerifyService, List[Any]) -> None

        self.service = service
        
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_req_order_no(self, req_order_no):
        # type: (str) -> FaceVerifyQueryAuthResultReqCall
        self.query_params['req_order_no'] = req_order_no
        return self

    def set_open_id(self, open_id):
        # type: (str) -> FaceVerifyQueryAuthResultReqCall
        self.query_params['open_id'] = open_id
        return self

    def set_employee_id(self, employee_id):
        # type: (str) -> FaceVerifyQueryAuthResultReqCall
        self.query_params['employee_id'] = employee_id
        return self

    def do(self):
        # type: () -> Response[FaceVerifyQueryAuthResultResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('face_verify/v1/query_auth_result', 'GET', [ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=FaceVerifyQueryAuthResultResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class FaceVerifyUploadFaceImageReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (FaceVerifyService, List[Any]) -> None

        self.service = service
        self.body = FormData()
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_image(self, image):
        # type: (IO[Any]) -> FaceVerifyUploadFaceImageReqCall
        self.body.add_file('image', FormDataFile(image))
        return self

    def set_open_id(self, open_id):
        # type: (str) -> FaceVerifyUploadFaceImageReqCall
        self.query_params['open_id'] = open_id
        return self

    def set_employee_id(self, employee_id):
        # type: (str) -> FaceVerifyUploadFaceImageReqCall
        self.query_params['employee_id'] = employee_id
        return self

    def do(self):
        # type: () -> Response[FaceVerifyUploadFaceImageResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('face_verify/v1/upload_face_image', 'POST', [ACCESS_TOKEN_TYPE_TENANT], self.body, output_class=FaceVerifyUploadFaceImageResult , request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request, Response, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.docs = DocService(self)
        



class DocService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def batch_update(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (DocBatchUpdateReqBody, str, str, int) -> DocBatchUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocBatchUpdateReqCall(self, body, request_opts=request_opts)

    def content(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DocContentReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocContentReqCall(self, request_opts=request_opts)

    def create(self, body, tenant_key=None, user_access_token=None, timeout=None):
        # type: (DocCreateReqBody, str, str, int) -> DocCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocCreateReqCall(self, body, request_opts=request_opts)

    def meta(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DocMetaReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocMetaReqCall(self, request_opts=request_opts)

    def raw_content(self, tenant_key=None, user_access_token=None, timeout=None):
        # type: (str, str, int) -> DocRawContentReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if tenant_key is not None:
            request_opts += [set_tenant_key(tenant_key)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return DocRawContentReqCall(self, request_opts=request_opts)



class DocBatchUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DocService, DocBatchUpdateReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_docToken(self, doc_token):
        # type: (str) -> DocBatchUpdateReqCall
        self.path_params['docToken'] = doc_token
        return self

    def do(self):
        # type: () -> Response[None]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('doc/v2/:docToken/batch_update', 'POST', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                      self.body, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocContentReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DocService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_docToken(self, doc_token):
        # type: (str) -> DocContentReqCall
        self.path_params['docToken'] = doc_token
        return self

    def do(self):
        # type: () -> Response[DocContentResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('doc/v2/:docToken/content', 'GET', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=DocContentResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (DocService, DocCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def do(self):
        # type: () -> Response[DocCreateResult]
        root_service = self.service.service

        conf = root_service.conf
        req = Request('doc/v2/create', 'POST', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                      self.body, output_class=DocCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocMetaReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DocService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_docToken(self, doc_token):
        # type: (str) -> DocMetaReqCall
        self.path_params['docToken'] = doc_token
        return self

    def do(self):
        # type: () -> Response[DocMetaResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('doc/v2/meta/:docToken', 'GET', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=DocMetaResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class DocRawContentReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (DocService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_docToken(self, doc_token):
        # type: (str) -> DocRawContentReqCall
        self.path_params['docToken'] = doc_token
        return self

    def do(self):
        # type: () -> Response[DocRawContentResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('doc/v2/:docToken/raw_content', 'GET', [ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_TENANT],
                      None, output_class=DocRawContentResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import *

from ....api import Request, Response, set_timeout, set_tenant_key, set_user_access_token, set_path_params, \
    set_query_params, set_response_stream, set_is_response_stream, FormData, FormDataFile
from ....config import Config
from ....consts import ACCESS_TOKEN_TYPE_TENANT, ACCESS_TOKEN_TYPE_USER, ACCESS_TOKEN_TYPE_APP
from .model import *


class Service(object):
    def __init__(self, conf):
        # type: (Config) -> None
        self.conf = conf
        self.apps = AppService(self)
        self.app_tables = AppTableService(self)
        self.app_table_fields = AppTableFieldService(self)
        self.app_table_records = AppTableRecordService(self)
        



class AppService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def get(self, user_access_token=None, timeout=None):
        # type: (str, int) -> AppGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppGetReqCall(self, request_opts=request_opts)


class AppTableService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def list(self, user_access_token=None, timeout=None):
        # type: (str, int) -> AppTableListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableListReqCall(self, request_opts=request_opts)


class AppTableFieldService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def list(self, user_access_token=None, timeout=None):
        # type: (str, int) -> AppTableFieldListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableFieldListReqCall(self, request_opts=request_opts)


class AppTableRecordService(object):
    def __init__(self, service):
        # type: (Service) -> None
        self.service = service

    def batch_delete(self, body, user_access_token=None, timeout=None):
        # type: (AppTableRecordBatchDeleteReqBody, str, int) -> AppTableRecordBatchDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableRecordBatchDeleteReqCall(self, body, request_opts=request_opts)

    def batch_create(self, body, user_access_token=None, timeout=None):
        # type: (AppTableRecordBatchCreateReqBody, str, int) -> AppTableRecordBatchCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableRecordBatchCreateReqCall(self, body, request_opts=request_opts)

    def get(self, user_access_token=None, timeout=None):
        # type: (str, int) -> AppTableRecordGetReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableRecordGetReqCall(self, request_opts=request_opts)

    def update(self, body, user_access_token=None, timeout=None):
        # type: (AppTableRecord, str, int) -> AppTableRecordUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableRecordUpdateReqCall(self, body, request_opts=request_opts)

    def delete(self, user_access_token=None, timeout=None):
        # type: (str, int) -> AppTableRecordDeleteReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableRecordDeleteReqCall(self, request_opts=request_opts)

    def list(self, user_access_token=None, timeout=None):
        # type: (str, int) -> AppTableRecordListReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableRecordListReqCall(self, request_opts=request_opts)

    def batch_update(self, body, user_access_token=None, timeout=None):
        # type: (AppTableRecordBatchUpdateReqBody, str, int) -> AppTableRecordBatchUpdateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableRecordBatchUpdateReqCall(self, body, request_opts=request_opts)

    def create(self, body, user_access_token=None, timeout=None):
        # type: (AppTableRecord, str, int) -> AppTableRecordCreateReqCall

        request_opts = []   # type: List[Callable[[Any], Any]]

        if timeout is not None:
            request_opts += [set_timeout(timeout)]

        if user_access_token is not None:
            request_opts += [set_user_access_token(user_access_token)]

        return AppTableRecordCreateReqCall(self, body, request_opts=request_opts)



class AppTableRecordBatchDeleteReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (AppTableRecordService, AppTableRecordBatchDeleteReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableRecordBatchDeleteReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_table_id(self, table_id):
        # type: (str) -> AppTableRecordBatchDeleteReqCall
        self.path_params['table_id'] = table_id
        return self

    def do(self):
        # type: () -> Response[AppTableRecordBatchDeleteResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('bitable/v1/apps/:app_token/tables/:table_id/records/batch_delete', 'POST', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=AppTableRecordBatchDeleteResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppTableRecordBatchCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (AppTableRecordService, AppTableRecordBatchCreateReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableRecordBatchCreateReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_table_id(self, table_id):
        # type: (str) -> AppTableRecordBatchCreateReqCall
        self.path_params['table_id'] = table_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> AppTableRecordBatchCreateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> Response[AppTableRecordBatchCreateResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('bitable/v1/apps/:app_token/tables/:table_id/records/batch_create', 'POST', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=AppTableRecordBatchCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppTableRecordGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (AppTableRecordService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableRecordGetReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_table_id(self, table_id):
        # type: (str) -> AppTableRecordGetReqCall
        self.path_params['table_id'] = table_id
        return self

    def set_record_id(self, record_id):
        # type: (str) -> AppTableRecordGetReqCall
        self.path_params['record_id'] = record_id
        return self

    def do(self):
        # type: () -> Response[AppTableRecordGetResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('bitable/v1/apps/:app_token/tables/:table_id/records/:record_id', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=AppTableRecordGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppTableRecordUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (AppTableRecordService, AppTableRecord, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableRecordUpdateReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_table_id(self, table_id):
        # type: (str) -> AppTableRecordUpdateReqCall
        self.path_params['table_id'] = table_id
        return self

    def set_record_id(self, record_id):
        # type: (str) -> AppTableRecordUpdateReqCall
        self.path_params['record_id'] = record_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> AppTableRecordUpdateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> Response[AppTableRecordUpdateResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('bitable/v1/apps/:app_token/tables/:table_id/records/:record_id', 'PUT', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=AppTableRecordUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppTableRecordDeleteReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (AppTableRecordService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableRecordDeleteReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_table_id(self, table_id):
        # type: (str) -> AppTableRecordDeleteReqCall
        self.path_params['table_id'] = table_id
        return self

    def set_record_id(self, record_id):
        # type: (str) -> AppTableRecordDeleteReqCall
        self.path_params['record_id'] = record_id
        return self

    def do(self):
        # type: () -> Response[DeleteRecord]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('bitable/v1/apps/:app_token/tables/:table_id/records/:record_id', 'DELETE', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=DeleteRecord, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppTableRecordListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (AppTableRecordService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableRecordListReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_table_id(self, table_id):
        # type: (str) -> AppTableRecordListReqCall
        self.path_params['table_id'] = table_id
        return self

    def set_view_id(self, view_id):
        # type: (str) -> AppTableRecordListReqCall
        self.query_params['view_id'] = view_id
        return self

    def set_page_token(self, page_token):
        # type: (str) -> AppTableRecordListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> AppTableRecordListReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> Response[AppTableRecordListResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('bitable/v1/apps/:app_token/tables/:table_id/records', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=AppTableRecordListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppTableRecordBatchUpdateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (AppTableRecordService, AppTableRecordBatchUpdateReqBody, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableRecordBatchUpdateReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_table_id(self, table_id):
        # type: (str) -> AppTableRecordBatchUpdateReqCall
        self.path_params['table_id'] = table_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> AppTableRecordBatchUpdateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> Response[AppTableRecordBatchUpdateResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('bitable/v1/apps/:app_token/tables/:table_id/records/batch_update', 'POST', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=AppTableRecordBatchUpdateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppTableRecordCreateReqCall(object):
    def __init__(self, service, body, request_opts=None):
        # type: (AppTableRecordService, AppTableRecord, List[Any]) -> None

        self.service = service
        self.body = body
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableRecordCreateReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_table_id(self, table_id):
        # type: (str) -> AppTableRecordCreateReqCall
        self.path_params['table_id'] = table_id
        return self

    def set_user_id_type(self, user_id_type):
        # type: (str) -> AppTableRecordCreateReqCall
        self.query_params['user_id_type'] = user_id_type
        return self

    def do(self):
        # type: () -> Response[AppTableRecordCreateResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('bitable/v1/apps/:app_token/tables/:table_id/records', 'POST', [ACCESS_TOKEN_TYPE_USER],
                      self.body, output_class=AppTableRecordCreateResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppGetReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (AppService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppGetReqCall
        self.path_params['app_token'] = app_token
        return self

    def do(self):
        # type: () -> Response[AppGetResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        req = Request('bitable/v1/apps/:app_token', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=AppGetResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppTableListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (AppTableService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableListReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_page_token(self, page_token):
        # type: (str) -> AppTableListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> AppTableListReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> Response[AppTableListResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('bitable/v1/apps/:app_token/tables', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=AppTableListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp


class AppTableFieldListReqCall(object):
    def __init__(self, service, request_opts=None):
        # type: (AppTableFieldService, List[Any]) -> None

        self.service = service
        
        self.path_params = {}   # type: Dict[str, Any]
        self.query_params = {}  # type: Dict[str, Any]

        if request_opts:
            self.request_opts = request_opts
        else:
            self.request_opts = []  # type: List[Any]

    def set_app_token(self, app_token):
        # type: (str) -> AppTableFieldListReqCall
        self.path_params['app_token'] = app_token
        return self

    def set_table_id(self, table_id):
        # type: (str) -> AppTableFieldListReqCall
        self.path_params['table_id'] = table_id
        return self

    def set_view_id(self, view_id):
        # type: (str) -> AppTableFieldListReqCall
        self.query_params['view_id'] = view_id
        return self

    def set_page_token(self, page_token):
        # type: (str) -> AppTableFieldListReqCall
        self.query_params['page_token'] = page_token
        return self

    def set_page_size(self, page_size):
        # type: (int) -> AppTableFieldListReqCall
        self.query_params['page_size'] = page_size
        return self

    def do(self):
        # type: () -> Response[AppTableFieldListResult]
        root_service = self.service.service

        conf = root_service.conf
        self.request_opts += [set_path_params(self.path_params)]
        self.request_opts += [set_query_params(self.query_params)]
        req = Request('bitable/v1/apps/:app_token/tables/:table_id/fields', 'GET', [ACCESS_TOKEN_TYPE_USER],
                      None, output_class=AppTableFieldListResult, request_opts=self.request_opts)
        resp = req.do(conf)
        return resp




# -*- coding: UTF-8 -*-

import time
from threading import Lock
from typing import Any, Dict, Tuple


class Store(object):
    """
    This is an interface to storage (Key, Value) pairs for sdk.
    """

    def get(self, key):  # type: (str) -> Tuple[bool, str]
        return False, ''

    def set(self, key, value, expire):  # type: (str, str, int) -> None
        """
        storage key, value into the store, value has an expire time.(unit: second)
        """
        pass


class ExpireValue(object):
    def __init__(self, value, expire):  # type: (str, int) -> None
        self.value = value
        self.expire = expire


class MemoryStore(Store):
    """
    This is an implement of `StoreInterface` which stores data in the memory
    """

    def __init__(self):  # type: () -> None
        self.data = {}  # type: Dict[str, ExpireValue]
        self.mutex = Lock()  # type: Lock

    def get(self, key):  # type: (str) -> Tuple[bool, str]
        # print('get %s' % key)
        self.mutex.acquire()
        try:
            val = self.data.get(key)
            if val is None:
                return False, ""
            else:
                if val.expire < int(time.time()):
                    self.data.pop(key)
                    return False, ""
                else:
                    return True, val.value
        finally:
            self.mutex.release()

    def set(self, key, value, expire):  # type: (str, str, int) -> None
        # print('put %s=%s, expire=%s' % (key, value, expire))
        """
        storage key, value into the store, value has an expire time.(unit: second)
        """
        self.mutex.acquire()
        try:
            self.data[key] = ExpireValue(value, expire)
        finally:
            self.mutex.release()
